@@ -1,7 +1,7 @@
 use crate::{
     client::Client,
     error::Error,
-    request::{self, AuditLogReason, AuditLogReasonError, Request, TryIntoRequest},
+    request::{self, AuditLogReason, Request, TryIntoRequest},
     response::{marker::EmptyBody, ResponseFuture},
     routing::Route,
 };
@@ -9,6 +9,7 @@ use twilight_model::id::{
     marker::{ChannelMarker, MessageMarker, WebhookMarker},
     Id,
 };
+use twilight_validate::request::{audit_reason as validate_audit_reason, ValidationError};
 
 /// Delete a message created by a webhook.
 ///
@@ -78,8 +79,10 @@ impl<'a> DeleteWebhookMessage<'a> {
 }
 
 impl<'a> AuditLogReason<'a> for DeleteWebhookMessage<'a> {
-    fn reason(mut self, reason: &'a str) -> Result<Self, AuditLogReasonError> {
-        self.reason.replace(AuditLogReasonError::validate(reason)?);
+    fn reason(mut self, reason: &'a str) -> Result<Self, ValidationError> {
+        validate_audit_reason(reason)?;
+
+        self.reason.replace(reason);
 
         Ok(self)
     }
